﻿using Ant.Core.WebApi.Model;
using Central.Control.WebApi.Config;
using Central.Control.WebApi.Log4net;
using Central.Control.WebApi.Models.Request;
using Central.Control.WebApi.Models.Response;
using Central.Control.WebApi.Service.Interface;
using Com.Alipay.Business;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;
using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Text;
using System.Web;
using System.Web.Http;
using System.Web.Http.Results;

namespace Central.Control.WebApi.Controllers
{
    /// <summary>
    /// 订单相关接口
    /// </summary>
    [RoutePrefix("api/order")]
    public class OrderController : ApiController
    {
        private readonly IOrderService _orderService;

        private readonly ILog4NetHelper _log4NetHelper;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="orderService"></param>
        public OrderController(IOrderService orderService,
            ILog4NetHelper log4NetHelper)
        {
            _orderService = orderService;
            _log4NetHelper = log4NetHelper;
        }

        /// <summary>
        /// 下单
        /// </summary>
        /// <param name="req"></param>
        /// <returns></returns>
        [HttpPost]
        [Route("")]
        public ApiResult<OrderResponseDto> Order(OrderRequestDto req)
        {
            return _orderService.Order(req);
        }

        /// <summary>
        /// 获取待烧烤的商品列表
        /// </summary>
        /// <returns></returns>
        [HttpGet]
        [Route("queueorders")]
        public ApiResult<List<QueueOrderResponseDto>> GetQueueOrders()
        {
            return _orderService.GetQueueOrders();
        }

        /// <summary>
        /// 回写流程状态
        /// </summary>
        /// <param name="req"></param>
        /// <returns></returns>
        [HttpPost]
        [Route("orderprocess")]
        public ApiResult OrderProcess(OrderProcessRequestDto req)
        {
            return _orderService.OrderProcess(req);
        }

        /// <summary>
        /// 支付宝支付回写
        /// </summary>
        /// <returns></returns>
        [AllowAnonymous]
        [HttpPost]
        [Route("alipaynotify")]
        public HttpResponseMessage AliPayNotify()
        {
            var result = _orderService.AliPayNotify();
            HttpResponseMessage responseMessage = new HttpResponseMessage { Content = new StringContent(result, Encoding.GetEncoding("UTF-8"), "text/plain") };
            return responseMessage;
        }

        /// <summary>
        /// 支付宝支付回写
        /// </summary>
        /// <returns></returns>
        [AllowAnonymous]
        [HttpGet]
        [Route("payredirect")]
        public RedirectResult PayRedirect(string url)
        {
            return this.Redirect(url);
        }

        /// <summary>
        /// 支付测试
        /// </summary>
        /// <returns></returns>
        [HttpGet]
        [Route("paytest")]
        public ApiResult<AlipayF2FPrecreateResult> PayTest()
        {
            return _orderService.PayTest();
        }
        
    }
}